@@ -3,6 +3,7 @@ from mojo.models import MojoModel, MojoSecrets
 from mojo.helpers import dates, logit
 from mojo.apps import metrics
 from mojo.helpers.settings import settings
+import uuid
 
 GROUP_LAST_ACTIVITY_FREQ = settings.get("GROUP_LAST_ACTIVITY_FREQ", 300)
 METRICS_TIMEZONE = settings.get("METRICS_TIMEZONE", "America/Los_Angeles")
@@ -41,6 +42,19 @@ class Group(MojoSecrets, MojoModel):
             "is_active": True
         }
         GRAPHS = {
+            "simple": {
+                "extra": ["timezone", "short_name", "thumbnail"],
+                "fields": [
+                    'uuid',
+                    'id',
+                    'name',
+                    'created',
+                    'modified',
+                    'is_active',
+                    'parent',
+                    'kind',
+                ]
+            },
             "basic": {
                 "fields": [
                     'id',
@@ -94,6 +108,20 @@ class Group(MojoSecrets, MojoModel):
     def timezone(self):
         return self.metadata.get("timezone", "America/Los_Angeles")
 
+    @property
+    def short_name(self):
+        return self.metadata.get("short_name", "")
+
+    @property
+    def thumbnail(self):
+        return None
+
+    def get_uuid(self):
+        if not self.uuid:
+            self.uuid = uuid.uuid4().hex
+            self.save(update_fields=["uuid"])
+        return self.uuid
+
     def get_local_day(self, dt_utc=None):
         return dates.get_local_day(self.timezone, dt_utc)
 
@@ -251,6 +279,7 @@ class Group(MojoSecrets, MojoModel):
         Invites a user to join the group.
         """
         from mojo.apps.account.models import User
+        email = email.strip().lower()
         user = User.objects.filter(email=email).last()
         ms = None
         if context is None:
